;; Generated package description from docbook.el  -*- no-byte-compile: t -*-
(define-package "docbook" "0.1" "Info-like viewer for DocBook" 'nil :commit "a59f87c0dc04bcfcf9f55a124658c2e7a585dbd2" :url "https://elpa.gnu.org/packages/docbook.html" :authors '(("Chong Yidong" . "cyd@gnu.org")) :maintainer '("Chong Yidong" . "cyd@gnu.org") :keywords '("docs" "help"))
